@@ -126,7 +126,7 @@ def find_channels(  channel_glob='*',
     max_sample_rate    -- A maximum sample rate to search for.
     timespan           -- Optional time span to limit available channel search to.  This may be an nds2.epoch or a tuple of [start, stop) times.
     host_server        -- str. Valid nds2 server.  Default is `nds.ligo-wa.caltech.edu`
-    port_number        --  int. Valid port from which to access the server.  Default is 31200
+    port_number        -- int. Valid port from which to access the server.  Default is 31200
     allow_data_on_tape -- str. String should be `True` or `False`.  Set to `True` if need really old data, is slower.
     gap_handler        -- str.  Defines how gaps in the data should be handled by nds2.  String default is 'STATIC_HANDLER_NAN'.
                           Usual nds2 default is 'ABORT_HANDLER', which kills your request if there's any unavailable data.
@@ -267,10 +267,43 @@ def find_channels(  channel_glob='*',
             print()
         except RuntimeError:
             print('\033[93m'+'RuntimeError: Failed to establish a connection[INFO: Error occurred trying to write to socket]'+'\033[0m')
-            print('Did you run `kinit albert.einstein@LIGO.ORG`?')
-            print('Are your nds2 parameters set correctly?')
+            print()
+            print('\033[93m'+'Did you run `kinit albert.einstein@LIGO.ORG`?'+'\033[0m')
+            print()
+            print('\033[93m'+'Are your nds2 parameters set correctly?'+'\033[0m')
+            print_nds2_params(params)
     return buffers
 
+def check_channels_existance(   channels,
+                                host_server='nds.ligo-wa.caltech.edu',
+                                port_number=31200,
+                                allow_data_on_tape='False',
+                                gap_handler='STATIC_HANDLER_NAN'):
+    '''Uses find_channels() to determine which channels exist in a list.
+    Returns nothing, outputs 
+    Input:
+    channels = list of channels
+    '''
+    print()
+    print(f'Checking existance of channel in list on {host_server}:{port_number}')
+    for chan in channels: 
+        buf = find_channels(chan, host_server=host_server, port_number=port_number, 
+            allow_data_on_tape=allow_data_on_tape, gap_handler=gap_handler, verbose=False) 
+        try: 
+            buf[0] 
+            print('\033[92m'+f'"{chan}" found''\033[0m') 
+        except IndexError: 
+            print('\033[93m'+f'"{chan}" does not exist''\033[0m') 
+                                                                                                            
+    return
+
+def print_nds2_params(params):
+    '''Print the nds2 parameters which govern data collection.
+    '''
+    for prm in params.parameter_list(): 
+        print(f'{prm} = {params.get(prm)}') 
+    return
+
 def make_array_from_buffers(buffers):
     '''
     Input:
@@ -375,11 +408,17 @@ def acquire_data(channels,
         params.set('GAP_HANDLER', gap_handler)
         buffers = nds2.fetch(channels, gps_start, gps_stop, params=params)
     except RuntimeError:
+        print()
         print('\033[93m'+'RuntimeError: Failed to establish a connection[INFO: Error occurred trying to write to socket]'+'\033[0m')
-        print('Did you run `kinit craig.cahillane@LIGO.ORG`?')
-        print('Are your nds2 parameters set correctly?')
-        print('Are you sure all the channels are valid?  Check with find_channels()')
-        sys.exit(0)
+        print()
+        print('\033[93m'+'Did you run `kinit craig.cahillane@LIGO.ORG`?'+'\033[0m')
+        print()
+        print('\033[93m'+'Are your nds2 parameters set correctly?'+'\033[0m')
+        print_nds2_params(params)
+        print()
+        print('\033[93m'+'Checking if channels are valid with find_channels():'+'\033[0m')
+        check_channels_existance(channels, host_server=host_server, port_number=port_number, allow_data_on_tape=allow_data_on_tape, gap_handler=gap_handler)
+        return None
 
     try:
         first_buff = buffers[0]
